@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Carp qw(croak);
 
@@ -90,6 +90,7 @@ IPC::ConcurrencyLimit - Lock-based limits on cooperative multi-processing
       path      => '/var/run/myapp', # an option to the locking strategy
     );
     
+    # NOTE: when $limit goes out of scope, the lock is released
     my $id = $limit->get_lock;
     if (not $id) {
       warn "Got none of the worker locks. Exiting.";
@@ -234,16 +235,22 @@ Steffen Mueller, C<smueller@cpan.org>
 
 Yves Orton
 
+David Morel
+
+Matt Koscica, C<mattk@cpan.org>
+
+Ivan Kruglov
+
 =head1 ACKNOWLEDGMENT
 
-This module was originally developed for booking.com.
-With approval from booking.com, this module was generalized
+This module was originally developed for Booking.com.
+With approval from Booking.com, this module was generalized
 and put on CPAN, for which the authors would like to express
 their gratitude.
 
 =head1 COPYRIGHT AND LICENSE
 
- (C) 2011, 2012 Steffen Mueller. All rights reserved.
+ (C) 2011-2015 Steffen Mueller. All rights reserved.
  
  This code is available under the same license as Perl version
  5.8.1 or higher.
